"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createTranspiler = void 0;
var tslib_1 = require("tslib");
var fs_1 = tslib_1.__importDefault(require("fs"));
var path_1 = require("path");
var typescript_1 = require("typescript");
var util_1 = require("util");
var create_imports_transformer_1 = require("./create-imports-transformer");
var readFile = util_1.promisify(fs_1.default.readFile);
/**
 * Create source code transpiler.
 * @internal
 * @param cwd - working dir
 * @param compilerOptions - typescript compiler options
 * @param transformers - list of custom transformers
 * @param resolve - dependencies resolver
 * @param preloadList - list of modules to preload
 */
var createTranspiler = function (cwd, compilerOptions, transformers, resolve, preloadList) {
    return function (file) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var source, result;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, readFile(file)];
                case 1:
                    source = (_a.sent()).toString('utf8');
                    result = typescript_1.transpileModule(source, {
                        fileName: path_1.basename(file),
                        compilerOptions: compilerOptions,
                        transformers: {
                            before: tslib_1.__spreadArrays(transformers, [
                                create_imports_transformer_1.createImportsTransformer(cwd, resolve, file, preloadList)
                            ])
                        }
                    });
                    return [2 /*return*/, result.outputText];
            }
        });
    }); };
};
exports.createTranspiler = createTranspiler;
//# sourceMappingURL=create-transpiler.js.map